@@ -12,8 +12,11 @@ import os
 import json
 import time
 import logging
+import tarfile
 from typing import Tuple, List, Dict, Any, Optional, Union, Type
 
+import shutil
+
 import numpy as np
 import numpy.typing as npt
 
@@ -244,7 +247,8 @@ def search_subdirs(dir_name: str) -> Tuple[List[str], List[str]]:
 def write_tar(target_dir: str, file_name: str) -> None:
     """
     The write_tar function takes a target directory and an output name as arguments.
-    It then creates a tar file with the given output name, and adds all files in the target directory to it.
+    It then creates a tar file with the given output name, and adds all files in the
+    target directory to it.
 
     :param target_dir:str: Used to Specify the directory that you want to compress.
     :param out_name:str: Used to Specify the name of the tar file that will be created.
@@ -253,11 +257,32 @@ def write_tar(target_dir: str, file_name: str) -> None:
     :doc-author: Julian M. Kleber
     """
 
-    import tarfile
+    with tarfile.open(file_name, "w") as tar:
+        for root, dir, files in os.walk(target_dir):
+            for file in files:
+                fullpath = os.path.join(root, file)
+                tar.add(fullpath, arcname=file)
+        tar.close()
 
-    tar = tarfile.open(file_name, "w")
-    for root, dir, files in os.walk(target_dir):
-        for file in files:
-            fullpath = os.path.join(root, file)
-            tar.add(fullpath, arcname=file)
-    tar.close()
+
+def copy_dir(old_dir: str, new_dir: str, overwrite=True) -> None:
+    """
+    The copy_dir function takes two arguments, old_dir and new_dir.
+    It copies all files from the old directory to the new directory.
+    If either of these directories do not end with a "/", it will be added.
+
+    :param old_dir:str: Used to Specify the directory that you want to copy from.
+    :param new_dir:str: Used to Specify the new directory that you want to copy your files into.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
+    """
+
+    check_make_dir(new_dir)
+    if not old_dir.endswith("/"):
+        old_dir += "/"
+    if not new_dir.endswith("/"):
+        new_dir += "/"
+    if overwrite and os.path.isdir(new_dir):
+        shutil.rmtree(new_dir)
+    shutil.copytree(old_dir, new_dir)
